@@ -1,7 +1,7 @@
 # coding: utf-8
 from django.apps import AppConfig
 from django.urls import reverse_lazy
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from octonet.mixins import OctonetAppMixin
 
 class Upgrade(OctonetAppMixin, AppConfig):
