@@ -712,7 +712,8 @@ class UserCreate(NetpermsMixin, UserFormMixin, OctonetMixin, FormView):
             # Set password
             # refs #12214 #352
             if password:
-                if gidNumber and gid and gid.startswith("docent"):
+                if ((gidNumber and gid and gid.startswith("docent")) or
+                        user_data.get('force_password_change')):
                     self.root_tree.lset(["users", "users", name, "password"], {'password': password, 'shadowLastChange': 0})
                 else:
                     self.root_tree.lset(["users", "users", name, "password"], password)
